// TODO:
//   * Migrate all previous taiko test steps:
//     * OO: /welcome and /healthcheck
//     * Check passwords and calendar app
//   * Split Nextcloud and Onlyoffice tests


// https://www.npmjs.com/package/cypress-iframe
import 'cypress-iframe';
const options = {
  // Filter out flood of cons:warn deprecation and other unimportant cons:info msgs
  collectTypes: ['cons:log', 'cons:error', 'cy:log', 'cy:xhr', 'cy:request', 'cy:intercept', 'cy:command'],
  // experimental and instable, use with care!
  enableContinuousLogging: true
}
require('cypress-terminal-report/src/installLogsCollector')(options);

describe('Test nextcloud', () => {
  it('passes', () => {

    function clearModal(selector, timeout = 5000, attempts = 0) {
      const wait = 300
      for (let i = 1; i < timeout; i += wait) {
        cy.log('Waited ' + i + 'ms')
        cy.get('body')
          .then($body => {
            if ($body.find(selector).length) {
              cy.get('body').type('{esc}')
            }
          })
      cy.wait(wait)
      }
    }

    cy.visit('/')
    cy.log(Cypress.env('USE_SSO_LOGIN'))

    if (Cypress.env('USE_SSO_LOGIN') == true) {
      // We should be redirected to the dashboard for SSO login automatically.
      cy.url().should('include', 'dashboard')
      cy.get('#identifier.form-control')
        .type(Cypress.env('SSO_USER'))
      cy.get('#password.form-control')
        .type(Cypress.env('SSO_PW'))
      cy.contains('Log in').click()
    } else {
      cy.get('#user').type(Cypress.env('NEXTCLOUD_ADMIN_USER'))
      cy.get('#password').type(Cypress.env('NEXTCLOUD_ADMIN_PW')+'{enter}')
    }

    cy.contains('Recommended files')

    // Wait for eventual welcome modal and close it
    clearModal('#firstrunwizard')

    // Create a new OO document with a random file name
    cy.visit('apps/files')
    cy.contains('button', 'New').click()
    const file_rand = 'test-' + Math.random().toString(16).substr(2, 12)
    cy.contains('button', 'New document').click()
    cy.get('input[placeholder="Filename"]').type('{selectAll}{del}' + file_rand + '.docx')
    cy.contains('span', 'Create').click()
    // With older Nextcloud, creating the new document this way would also open
    // it automatically. It seems with newer nextcloud/onlyoffice that is no
    // longer the case.
    // Ah with 29 it seems to work again. Keeping this in commented form in
    // case it breaks again.
    // cy.contains('a:not(.recommendation)', file_rand).should('exist').click()

    // Test Onlyoffice
    cy.frameLoaded('#onlyofficeFrame')
    cy.iframe('#onlyofficeFrame').within(() => {
      cy.frameLoaded('[name="frameEditor"]')
      cy.iframe('[name="frameEditor"]').within(() => {
        cy.get('#id-toolbar-btn-italic').should('be.visible').click({timeout: 60000})
        cy.get('#id_main').click().type('Hi from Cypress!')
      })
    })
  })
})
